==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/zh_TW.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "相簿",
    "There was a problem reading files from this album" : "從相簿讀取檔案時發生問題",
    "Aborting preview. Could not find the file" : "預覽終止，無法找到該檔案",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server url" : "無效的伺服器 URL",
    "Gallery view" : "瀏覽相簿",
    "Could not load the description" : "無法載入敘述",
    "Could not load the description: " : "無法載入敘述：",
    "Copyright" : "著作權",
    "Could not load the copyright notice: " : "無法載入版權聲明：",
    "Copyright notice" : "版權聲明",
    "Link to copyright document" : "連結到著作權相關文件",
    "This application may not work properly on your browser." : "這個應用程式可能無法在你的瀏覽器正確執行",
    "For an improved experience, please install one of the following alternatives" : "請安裝以下的替代軟體，以獲得更好的使用者體驗",
    "Your browser is not supported!" : "不支援您的瀏覽器！",
    "please install one of the following alternatives" : "請安裝以下的替代軟體",
    "Album cannot be shown" : "無法顯示相簿",
    "No media files found" : "找不到媒體檔案",
    "Upload pictures in the files app to display them here" : "在「檔案」應用程式中上傳圖片，就會顯示在這邊",
    "Upload new files via drag and drop or by using the [+] button above" : "拖曳檔案來上傳，或是按上方的 [+] 按鈕",
    "Configuration error" : "設定錯誤",
    "New" : "新增",
    "Hide Album" : "隱藏相簿",
    "Could not hide album" : "無法隱藏相簿",
    "Error loading slideshow template" : "載入幻燈片樣板時發生錯誤",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>錯誤！</strong>無法產生此檔案的預覽圖<br>請前往下一張幻燈片，我們會將這張圖片從幻燈片移除",
    "Next" : "下一張",
    "Play" : "播放",
    "Pause" : "暫停",
    "Previous" : "上一張",
    "Close" : " 關閉",
    "Download" : "下載",
    "Toggle background" : "切換背景",
    "Delete" : "刪除",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Upload" : "上傳",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "Error while changing permissions" : "修改權限時發生錯誤",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "Share with users or groups …" : "與用戶或群組分享 ...",
    "Share with users, groups or remote users …" : "與用戶，群組或是遠端使用者分享 ...",
    "Share" : "分享",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "要與在其他伺服器上的人分享，請使用此格式 username@example.com/cloud",
    "Share link" : "分享連結",
    "The public link will expire no later than {days} days after it is created" : "這個公開連結會在 {days} 天內失效",
    "Link" : "連結",
    "Password protect" : "密碼保護",
    "Password" : "密碼",
    "Choose a password for the public link" : "為公開連結選一個密碼",
    "Allow editing" : "允許編輯",
    "Email link to person" : "將連結 email 給別人",
    "Send" : "寄出",
    "Set expiration date" : "指定到期日",
    "Expiration" : "過期",
    "Expiration date" : "到期日",
    "An error occured. Please try again" : "發生錯誤，請重試",
    "Adding user..." : "新增使用者…",
    "group" : "群組",
    "remote" : "遠端",
    "Resharing is not allowed" : "不允許重新分享",
    "Error while retrieving shares" : "取得分享時發生錯誤",
    "Unshare" : "取消分享",
    "notify by email" : "以 email 通知",
    "can share" : "可分享",
    "can edit" : "可編輯",
    "access control" : "存取控制",
    "create" : "建立",
    "change" : "更動",
    "delete" : "刪除",
    "Password protected" : "受密碼保護",
    "Error unsetting expiration date" : "取消到期日設定失敗",
    "Error setting expiration date" : "設定到期日發生錯誤",
    "Sending ..." : "正在傳送…",
    "Email sent" : "Email 已寄出",
    "Warning" : "警告",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Sort by date" : "由日期排序",
    "Sort by name" : "由名稱排序",
    "Cancel upload" : "取消上傳",
    "Album information" : "相簿資訊",
    "File list" : "檔案列表",
    "Sorry, this file could not be found." : "抱歉，找不到此檔案。",
    "Reasons might be:" : "可能的原因：",
    "the wrong file ID was provided" : "提供了錯誤的檔案ID",
    "the file was removed" : "檔案已經被移除",
    "the file is corrupt" : "檔案已經損毀",
    "the encryption key is missing" : "遺失加密鑰匙",
    "Here is the error message returned by the server: " : "伺服器回傳的錯誤訊息：",
    "For more information, please contact your friendly Nextcloud administrator." : "如欲取得更多資訊，請您聯絡您的 Nextcloud 系統管理員",
    "Sorry, but the server could not fulfill your request." : "很抱歉，伺服器無法完成您的請求",
    "Possible reasons for the problem:" : "造成此問題可能的原因：",
    "a conflicting app was installed" : "安裝了會造成衝突的 app",
    "a required component is missing or was disconnected" : "必要的元件遺失了或是已經失去連線",
    "the filesystem is not readable" : "該檔案系統無法讀取",
    "For more information, please contact your friendly ownCloud administrator." : "如欲取得更多資訊，請您聯絡您的 ownCloud 系統管理員",
    "Sorry, this link doesn't seem to work anymore." : "抱歉，此連結已經失效",
    "the item was removed" : "項目已經移除",
    "the link has expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more information, please ask the person who has sent you this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Picture view" : "檢視圖片"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/zh_TW.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "相簿",
    "There was a problem reading files from this album" : "從相簿讀取檔案時發生問題",
    "Aborting preview. Could not find the file" : "預覽終止，無法找到該檔案",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server url" : "無效的伺服器 URL",
    "Could not load the description" : "無法載入敘述",
    "Could not load the description: " : "無法載入敘述：",
    "Copyright" : "著作權",
    "Could not load the copyright notice: " : "無法載入版權聲明：",
    "Copyright notice" : "版權聲明",
    "Link to copyright document" : "連結到著作權相關文件",
    "This application may not work properly on your browser." : "這個應用程式可能無法在你的瀏覽器正確執行",
    "For an improved experience, please install one of the following alternatives" : "請安裝以下的替代軟體，以獲得更好的使用者體驗",
    "Your browser is not supported!" : "不支援您的瀏覽器！",
    "please install one of the following alternatives" : "請安裝以下的替代軟體",
    "Album cannot be shown" : "無法顯示相簿",
    "No media files found" : "找不到媒體檔案",
    "Upload pictures in the Files app to display them here" : "在檔案應用中上傳圖片以在這裡查看",
    "Upload new files via drag and drop or by using the [+] button above" : "拖曳檔案來上傳，或是按上方的 [+] 按鈕",
    "Configuration error" : "設定錯誤",
    "New" : "新增",
    "Hide Album" : "隱藏相簿",
    "Could not hide album" : "無法隱藏相簿",
    "Error loading slideshow template" : "載入幻燈片樣板時發生錯誤",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>錯誤！</strong>無法產生此檔案的預覽圖<br>請前往下一張幻燈片，我們會將這張圖片從幻燈片移除",
    "Next" : "下一張",
    "Play" : "播放",
    "Pause" : "暫停",
    "Previous" : "上一張",
    "Close" : " 關閉",
    "Download" : "下載",
    "Toggle background" : "切換背景",
    "Delete" : "刪除",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 並不是經允許的檔案類型",
    "Upload" : "上傳",
    "Error" : "錯誤",
    "Error while sharing" : "分享時發生錯誤",
    "Error while unsharing" : "取消分享時發生錯誤",
    "Error while changing permissions" : "修改權限時發生錯誤",
    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}",
    "Shared with you by {owner}" : "{owner} 已經和您分享",
    "Share with users or groups …" : "與用戶或群組分享 ...",
    "Share with users, groups or remote users …" : "與用戶，群組或是遠端使用者分享 ...",
    "Share" : "分享",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "要與在其他伺服器上的人分享，請使用此格式 username@example.com/cloud",
    "Share link" : "分享連結",
    "The public link will expire no later than {days} days after it is created" : "這個公開連結會在 {days} 天內失效",
    "Link" : "連結",
    "Password protect" : "密碼保護",
    "Password" : "密碼",
    "Choose a password for the public link" : "為公開連結選一個密碼",
    "Allow editing" : "允許編輯",
    "Email link to person" : "將連結 email 給別人",
    "Send" : "寄出",
    "Set expiration date" : "指定到期日",
    "Expiration" : "過期",
    "Expiration date" : "到期日",
    "This list is maybe truncated - please refine your search term to see more results." : "這個列表有可能並不完全 - 請使用更好的搜尋字眼以查看更多的結果",
    "No users or groups found for {search}" : "找不到與 {search} 有關的用戶或群組",
    "No users found for {search}" : "找不到與 {search} 有關的用戶",
    "An error occured. Please try again" : "發生錯誤，請重試",
    "Adding user..." : "新增使用者…",
    "group" : "群組",
    "remote" : "遠端",
    "Resharing is not allowed" : "不允許重新分享",
    "Error while retrieving shares" : "取得分享時發生錯誤",
    "Unshare" : "取消分享",
    "notify by email" : "以 email 通知",
    "can share" : "可分享",
    "can edit" : "可編輯",
    "access control" : "存取控制",
    "create" : "建立",
    "change" : "更動",
    "delete" : "刪除",
    "Password protected" : "受密碼保護",
    "Error unsetting expiration date" : "取消到期日設定失敗",
    "Error setting expiration date" : "設定到期日發生錯誤",
    "Sending ..." : "正在傳送…",
    "Email sent" : "Email 已寄出",
    "Warning" : "警告",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Sort by date" : "由日期排序",
    "Sort by name" : "由名稱排序",
    "Cancel upload" : "取消上傳",
    "Album information" : "相簿資訊",
    "File list" : "檔案列表",
    "Sorry, this file could not be found." : "抱歉，找不到此檔案。",
    "Reasons might be:" : "可能的原因：",
    "the wrong file ID was provided" : "提供了錯誤的檔案ID",
    "the file was removed" : "檔案已經被移除",
    "the file is corrupt" : "檔案已經損毀",
    "the encryption key is missing" : "遺失加密鑰匙",
    "Here is the error message returned by the server: " : "伺服器回傳的錯誤訊息：",
    "For more information, please contact your friendly Nextcloud administrator." : "如欲取得更多資訊，請您聯絡您的 Nextcloud 系統管理員",
    "Sorry, but the server could not fulfill your request." : "很抱歉，伺服器無法完成您的請求",
    "Possible reasons for the problem:" : "造成此問題可能的原因：",
    "a conflicting app was installed" : "安裝了會造成衝突的 app",
    "a required component is missing or was disconnected" : "必要的元件遺失了或是已經失去連線",
    "the filesystem is not readable" : "該檔案系統無法讀取",
    "Sorry, this link doesn't seem to work anymore." : "抱歉，此連結已經失效",
    "the item was removed" : "項目已經移除",
    "the link has expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more information, please ask the person who has sent you this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Picture view" : "檢視圖片",
    "Gallery view" : "瀏覽相簿"
},
"nplurals=1; plural=0;");
